stalker.ext.auth.check_password — Stalker v0.1.1.a9 documentation

### Navigation

- index
- next |
- previous |
- Stalker v0.1.1.a9 documentation »

# stalker.ext.auth.check_password

static `auth.` `check_password`(raw_password, enc_password)

  Checks the given raw password.

  Checks the given raw password with the given encrypted password. Handles the encryption process behind the scene.

  Parameters: | raw_password – The password. enc_password – The encrypted password.
  Returns: | bool

### Navigation

- index
- next |
- previous |
- Stalker v0.1.1.a9 documentation »